@@ -13,33 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-
-from google.cloud.artifactregistry_v1beta2.types import apt_artifact
-from google.cloud.artifactregistry_v1beta2.types import file
-from google.cloud.artifactregistry_v1beta2.types import package
-from google.cloud.artifactregistry_v1beta2.types import repository
-from google.cloud.artifactregistry_v1beta2.types import repository as gda_repository
-from google.cloud.artifactregistry_v1beta2.types import settings
-from google.cloud.artifactregistry_v1beta2.types import tag
-from google.cloud.artifactregistry_v1beta2.types import tag as gda_tag
-from google.cloud.artifactregistry_v1beta2.types import version
-from google.cloud.artifactregistry_v1beta2.types import yum_artifact
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-from .base import ArtifactRegistryTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+
+from google.cloud.artifactregistry_v1beta2.types import apt_artifact, file, package
+from google.cloud.artifactregistry_v1beta2.types import repository as gda_repository
+from google.cloud.artifactregistry_v1beta2.types import repository
+from google.cloud.artifactregistry_v1beta2.types import settings
+from google.cloud.artifactregistry_v1beta2.types import tag
+from google.cloud.artifactregistry_v1beta2.types import tag as gda_tag
+from google.cloud.artifactregistry_v1beta2.types import version, yum_artifact
+
+from .base import DEFAULT_CLIENT_INFO, ArtifactRegistryTransport
 
 
 class ArtifactRegistryGrpcTransport(ArtifactRegistryTransport):
@@ -251,8 +246,7 @@ class ArtifactRegistryGrpcTransport(ArtifactRegistryTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -927,5 +921,9 @@ class ArtifactRegistryGrpcTransport(ArtifactRegistryTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ArtifactRegistryGrpcTransport",)
